@@ -1,8 +1,9 @@
 package ExtUtils::MM_DOS;
 
 use strict;
+use warnings;
 
-our $VERSION = '7.36';
+our $VERSION = '7.48';
 $VERSION =~ tr/_//d;
 
 require ExtUtils::MM_Any;
@@ -21,10 +22,10 @@ ExtUtils::MM_DOS - DOS specific subclass of ExtUtils::MM_Unix
 
 =head1 DESCRIPTION
 
-This is a subclass of ExtUtils::MM_Unix which contains functionality
+This is a subclass of L<ExtUtils::MM_Unix> which contains functionality
 for DOS.
 
-Unless otherwise stated, it works just like ExtUtils::MM_Unix
+Unless otherwise stated, it works just like ExtUtils::MM_Unix.
 
 =head2 Overridden methods
 
