@@ -45,7 +45,7 @@ declare the output character set as UTF-8 before parsing, like so:
 package Pod::Simple::XHTML;
 use strict;
 use vars qw( $VERSION @ISA $HAS_HTML_ENTITIES );
-$VERSION = '3.40';
+$VERSION = '3.41';
 use Pod::Simple::Methody ();
 @ISA = ('Pod::Simple::Methody');
 
@@ -400,6 +400,8 @@ sub start_head1 {  $_[0]{'in_head'} = 1; $_[0]{htext} = ''; }
 sub start_head2 {  $_[0]{'in_head'} = 2; $_[0]{htext} = ''; }
 sub start_head3 {  $_[0]{'in_head'} = 3; $_[0]{htext} = ''; }
 sub start_head4 {  $_[0]{'in_head'} = 4; $_[0]{htext} = ''; }
+sub start_head5 {  $_[0]{'in_head'} = 5; $_[0]{htext} = ''; }
+sub start_head6 {  $_[0]{'in_head'} = 6; $_[0]{htext} = ''; }
 
 sub start_item_number {
     $_[0]{'scratch'} = "</li>\n" if ($_[0]{'in_li'}->[-1] && pop @{$_[0]{'in_li'}});
@@ -483,6 +485,8 @@ sub end_head1       { shift->_end_head(@_); }
 sub end_head2       { shift->_end_head(@_); }
 sub end_head3       { shift->_end_head(@_); }
 sub end_head4       { shift->_end_head(@_); }
+sub end_head5       { shift->_end_head(@_); }
+sub end_head6       { shift->_end_head(@_); }
 
 sub end_item_bullet { $_[0]{'scratch'} .= '</p>'; $_[0]->emit }
 sub end_item_number { $_[0]{'scratch'} .= '</p>'; $_[0]->emit }
