@@ -21,6 +21,8 @@ struct xpvcv {
 This section documents functions to manipulate CVs which are code-values,
 meaning subroutines.  For more information, see L<perlguts>.
 
+=for apidoc Ayh||CV
+
 =for apidoc ADmnU||Nullcv
 Null CV pointer.
 
@@ -124,7 +126,7 @@ See L<perlguts/Autoloading with XSUBs>.
 #define CVf_NODEBUG	0x0200	/* no DB::sub indirection for this CV
 				   (esp. useful for special XSUBs) */
 #define CVf_CVGV_RC	0x0400	/* CvGV is reference counted */
-#ifdef PERL_CORE
+#if defined(PERL_CORE) || defined(PERL_EXT)
 # define CVf_SLABBED	0x0800	/* Holds refcount on op slab  */
 #endif
 #define CVf_DYNFILE	0x1000	/* The filename is malloced  */
