@@ -204,7 +204,19 @@ PERLVARA(I, sv_immortals, 4, SV)
 
 PERLVAR(I, padname_undef,	PADNAME)
 PERLVAR(I, padname_const,	PADNAME)
-PERLVAR(I, Sv,		SV *)		/* used to hold temporary values */
+
+/*
+=for apidoc Cmn||PL_Sv
+
+A scratch pad SV for whatever temporary use you need.  Chiefly used as a
+fallback by macros on platforms where L<perlapi/PERL_USE_GCC_BRACE_GROUPS>> is
+unavailable, and which would otherwise would evaluate their SV parameter more
+than once.
+
+=cut
+*/
+PERLVAR(I, Sv,		SV *)
+
 PERLVAR(I, parser,	yy_parser *)	/* current parser state */
 
 PERLVAR(I, stashcache,	HV *)		/* Cache to speed up S_method_common */
