@@ -73,6 +73,19 @@ sub multi_char_folds ($$) {
     die "Incorrect format '$format' for Case_Folding inversion map"
                                                         unless $format eq 'al';
 
+    my %inverse_latin1_folds;
+    for my $i (0 .. @$cp_ref - 1) {
+        next if ref $folds_ref->[$i];   # multi-char fold
+        next if $folds_ref->[$i] == 0;  # Not folded
+        my $cp_base = $cp_ref->[$i];
+
+        for my $j ($cp_base .. $cp_ref->[$i+1] - 1) {
+            my $folded_base = $folds_ref->[$i];
+            next if $folded_base > 255;         # only interested in Latin1
+            push @{$inverse_latin1_folds{$folded_base + $j - $cp_base}}, $j;
+        }
+    }
+
     my @folds;
     my @output_folds;
 
@@ -111,27 +124,27 @@ sub multi_char_folds ($$) {
         # Skip if something else already has this fold
         next if grep { $_ eq $fold } @output_folds;
 
-        if ($type eq 'u') {
-            push @output_folds, $fold;
-        }   # Skip if wants only all-ascii folds, and there is a non-ascii
-        elsif (! grep { chr($_) =~ /[^[:ascii:]]/ } @folds) {
-
-            # If the fold is to a cased letter, replace the entry with an
-            # array which also includes its upper case.
-            my $this_fold_ref = \@folds;
-            for my $j (0 .. @$this_fold_ref - 1) {
-                my $this_ord = $this_fold_ref->[$j];
-                if (chr($this_ord) =~ /\p{Cased}/) {
-                    my $uc = ord(uc(chr($this_ord)));
-                    undef $this_fold_ref->[$j];
-                    @{$this_fold_ref->[$j]} = ( $this_ord, $uc);
-                }
+        # If the fold is to a cased letter, replace the entry with an
+        # array which also includes its upper case.
+        my $this_fold_ref = \@folds;
+        for my $j (0 .. @$this_fold_ref - 1) {
+            my $this_ord = $this_fold_ref->[$j];
+            undef $this_fold_ref->[$j];
+            
+            # If the fold is to a Latin1-range cased letter, replace the entry
+            # with an array which also includes everything that folds to it.
+            if (exists $inverse_latin1_folds{$this_ord}) {
+                push @{$this_fold_ref->[$j]},
+                      ( $this_ord, @{$inverse_latin1_folds{$this_ord}} );
+            }
+            else {  # Otherwise, just itself. (gen_combinations() needs a ref)
+                @{$this_fold_ref->[$j]} = ( $this_ord );
             }
-
-            # Then generate all combinations of upper/lower case of the fold.
-            push @output_folds, gen_combinations($this_fold_ref);
-
         }
+
+        # Then generate all combinations of upper/lower case of the fold.
+        push @output_folds, gen_combinations($this_fold_ref);
+
     }
 
     # \x17F is the small LONG S, which folds to 's'.  Both Capital and small
