@@ -20,7 +20,7 @@
 # will be worked over by t/op/inc.t
 
 $| = 1;
-$Level = 1;
+our $Level = 1;
 my $test = 1;
 my $planned;
 my $noplan;
@@ -30,9 +30,11 @@ my $Perl;       # Safer version of $^X set by which_perl()
 $::IS_ASCII  = ord 'A' ==  65;
 $::IS_EBCDIC = ord 'A' == 193;
 
-$TODO = 0;
-$NO_ENDING = 0;
-$Tests_Are_Passing = 1;
+# This is 'our' to enable harness to account for TODO-ed tests in
+# overall grade of PASS or FAIL
+our $TODO = 0;
+our $NO_ENDING = 0;
+our $Tests_Are_Passing = 1;
 
 # Use this instead of print to avoid interference while testing globals.
 sub _print {
@@ -304,7 +306,7 @@ eval 'sub re::is_regexp { ref($_[0]) eq "Regexp" }'
 
 # keys are the codes \n etc map to, values are 2 char strings such as \n
 my %backslash_escape;
-foreach my $x (split //, 'nrtfa\\\'"') {
+foreach my $x (split //, 'enrtfa\\\'"') {
     $backslash_escape{ord eval "\"\\$x\""} = "\\$x";
 }
 # A way to display scalars containing control characters and Unicode.
@@ -1023,7 +1025,7 @@ sub _fresh_perl {
 
     # Use the first line of the program as a name if none was given
     unless( $name ) {
-        ($first_line, $name) = $prog =~ /^((.{1,50}).*)/;
+        (my $first_line, $name) = $prog =~ /^((.{1,50}).*)/;
         $name = $name . '...' if length $first_line > length $name;
     }
 
@@ -1101,7 +1103,6 @@ sub fresh_perl_like {
 #   regex - the expected output is a regular expression
 #   random - all lines match but in any order
 #   fatal - the code will fail fatally (croak, die)
-#   nonfatal - the code is not expected to fail fatally
 #
 # If the actual output contains a line "SKIPPED" the test will be
 # skipped.
@@ -1112,6 +1113,7 @@ sub fresh_perl_like {
 # If the global variable $FATAL is true then OPTION fatal is the
 # default.
 
+our $FATAL;
 sub _setup_one_file {
     my $fh = shift;
     # Store the filename as a program that started at line 0.
@@ -1198,6 +1200,7 @@ sub run_multiple_progs {
 
     my $tmpfile = tempfile();
 
+    my $count_failures = 0;
     my ($file, $line);
   PROGRAM:
     while (defined ($line = shift @prgs)) {
@@ -1231,10 +1234,12 @@ sub run_multiple_progs {
 	    }
 	}
 
-	my $name = '';
-	if ($prog =~ s/^#\s*NAME\s+(.+)\n//m) {
-	    $name = $1;
-	}
+    my $name = '';
+    if ($prog =~ s/^#\s*NAME\s+(.+)\n//m) {
+        $name = $1;
+    } elsif (defined $file) {
+        $name = "test from $file at line $line";
+    }
 
 	if ($reason{skip}) {
 	SKIP:
@@ -1306,7 +1311,7 @@ sub run_multiple_progs {
 	my $option_regex = 0;
 	my $option_random = 0;
 	my $fatal = $FATAL;
-	if ($expected =~ s/^OPTIONS? (.+)(?:\n|\Z)//) {
+	if ($expected =~ s/^OPTIONS? (.+)\n//) {
 	    foreach my $option (split(' ', $1)) {
 		if ($option eq 'regex') { # allow regular expressions
 		    $option_regex = 1;
@@ -1317,10 +1322,6 @@ sub run_multiple_progs {
 		elsif ($option eq 'fatal') { # perl should fail
 		    $fatal = 1;
 		}
-                elsif ($option eq 'nonfatal') {
-                    # used to turn off default fatal
-                    $fatal = 0;
-                }
 		else {
 		    die "$0: Unknown OPTION '$option'\n";
 		}
@@ -1358,19 +1359,24 @@ sub run_multiple_progs {
 	local $::TODO = $reason{todo};
 
 	unless ($ok) {
-	    my $err_line = "PROG: $switch\n$prog\n" .
-			   "EXPECTED:\n$expected\n";
-	    $err_line   .= "EXIT STATUS: != 0\n" if $fatal;
-	    $err_line   .= "GOT:\n$results\n";
-	    $err_line   .= "EXIT STATUS: " . ($status >> 8) . "\n" if $fatal;
-	    if ($::TODO) {
-		$err_line =~ s/^/# /mg;
-		print $err_line;  # Harness can't filter it out from STDERR.
-	    }
-	    else {
-		print STDERR $err_line;
-	    }
-	}
+        my $err_line = '';
+        $err_line   .= "FILE: $file ; line $line\n" if defined $file;
+        $err_line   .= "PROG: $switch\n$prog\n" .
+			           "EXPECTED:\n$expected\n";
+        $err_line   .= "EXIT STATUS: != 0\n" if $fatal;
+        $err_line   .= "GOT:\n$results\n";
+        $err_line   .= "EXIT STATUS: " . ($status >> 8) . "\n" if $fatal;
+        if ($::TODO) {
+            $err_line =~ s/^/# /mg;
+            print $err_line;  # Harness can't filter it out from STDERR.
+        }
+        else {
+            print STDERR $err_line;
+            ++$count_failures;
+            die "PERL_TEST_ABORT_FIRST_FAILURE set Test Failure"
+                if $ENV{PERL_TEST_ABORT_FIRST_FAILURE};
+        }
+    }
 
         if (defined $file) {
             _ok($ok, "at $file line $line", $name);
@@ -1388,6 +1394,20 @@ sub run_multiple_progs {
 	    File::Path::rmtree $_ if -d $_;
 	}
     }
+
+    if ( $count_failures ) {
+        print STDERR <<'EOS';
+#
+# Note: 'run_multiple_progs' run has one or more failures
+#        you can consider setting the environment variable
+#        PERL_TEST_ABORT_FIRST_FAILURE=1 before running the test
+#        to stop on the first error.
+#
+EOS
+    }
+
+
+    return;
 }
 
 sub can_ok ($@) {
@@ -1418,7 +1438,7 @@ sub can_ok ($@) {
 sub new_ok {
     my($class, $args, $obj_name) = @_;
     $args ||= [];
-    $object_name = "The object" unless defined $obj_name;
+    $obj_name = "The object" unless defined $obj_name;
 
     local $Level = $Level + 1;
 
@@ -1427,7 +1447,7 @@ sub new_ok {
     my $error = $@;
 
     if($ok) {
-        object_ok($obj, $class, $object_name);
+        object_ok($obj, $class, $obj_name);
     }
     else {
         ok( 0, "new() died" );
@@ -1699,7 +1719,7 @@ sub watchdog ($;$)
 		if ($is_cygwin) {
 		    # sometimes the above isn't enough on cygwin
 		    sleep 1; # wait a little, it might have worked after all
-		    system("/bin/kill -f $pid_to_kill");
+		    system("/bin/kill -f $pid_to_kill") if kill(0, $pid_to_kill);
 		}
             }
 
